package com.taleo.integration.client.customstep.csv;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.lang.StringEscapeUtils;

/**
 * Post-processing step to remove all HTML tags and leave only text content. In
 * fact, it removes any tag starting with < and ending with >, which also
 * includes XML tags. It also unescapes the HTML content, so &nbsp will become a
 * space, and all entity characters (e.g. &#39;) will be translated back to
 * their original character.
 * <p>
 * This step takes all parameters from its base class
 * {@link com.taleo.integration.client.customstep.csv.BaseTransformPostStep}.
 * <p>
 * This class is dependent on:
 * <ul>
 * <li><a href="http://commons.apache.org/lang/">Apache Commons Lang</a>
 * (commons-lang-2.4.jar)</li>
 * </ul>
 * Here is an example of how to define this custom step in the TCC configuration
 * file.
 * <p>
 * <img src="doc-files/RemoveHTMLPostStep-1.png" />
 * 
 * @see BaseTransformPostStep
 * @author Romain Guay, Oracle Corporation
 */
public class RemoveHTMLPostStep extends BaseTransformPostStep {

	private final static Pattern PATTERN = Pattern.compile(
			"\\<(!--.*?--|.*?)\\>", Pattern.DOTALL);

	/**
	 * Constructor without arguments.
	 */
	public RemoveHTMLPostStep() {
		super();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.taleo.integration.client.step.BaseCustomStep#getIdentifier()
	 */
	public String getIdentifier() {
		return "RemoveHTMLPostStep";
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.taleo.integration.client.step.BaseCustomStep#getDescription()
	 */
	public String getDescription() {
		return "Post-processing step to remove HTML tags.";
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.taleo.integration.client.step.BaseCustomStep#getName()
	 */
	public String getName() {
		return "RemoveHTMLPostStep";
	}

	/**
	 * Transform the given value by applying a decode.
	 * 
	 * @param value
	 *            The value to transform.
	 * @return The transformed value.
	 */
	protected String transform(String value) {
		value = StringEscapeUtils.unescapeHtml(value);
		Matcher matcher_tags = PATTERN.matcher(value);
		value = matcher_tags.replaceAll("");
		return value.trim();
	}

}
