package com.taleo.integration.client.customstep.lrd;

import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;

/**
 * Abstract date provider.
 * <p>
 * Offers a function to subtract a given number of minutes to the actual server
 * time to avoid timing issues because of database commit occurring on a
 * different server. The default adjustment is 10 minutes and can be changed
 * using the
 * "-Dcom.taleo.integration.client.lrd.filtering.minute.adjustment.computer"
 * Java argument.
 * 
 * @author Romain Guay - Taleo Corporation
 * 
 */
abstract class AbstractDateProvider implements DateProvider {

	/**
	 * Adjust the specified time using the default minute adjustment or the
	 * system property value.
	 * 
	 * @param date
	 *            The date to be adjusted
	 */
	protected Date adjustTime(Date date) {
		int lrdMinuteAdjustment = DEFAULT_LRD_MINUTE_ADJUSTMENT;
		try {
			// Read the system property for minute adjustment.
			lrdMinuteAdjustment = Integer.parseInt(System
					.getProperty(PROP_MINUTE_ADJUSTEMENT));
		} catch (NumberFormatException e) {
			// Invalid property value: keep default value.
		}

		// Remove x minutes from the given date.
		Calendar cal = GregorianCalendar.getInstance();
		cal.setTime(date);
		cal.add(Calendar.MINUTE, lrdMinuteAdjustment * -1);
		return cal.getTime();
	}
}
