package com.taleo.integration.client.customstep.lrd;

import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;

/**
 * Date provider that uses the date it is given. <br>
 * 
 * @author Romain Guay - Taleo
 * 
 */
public class FixedDateProvider extends AbstractDateProvider {

	/**
	 * The date.
	 */
	private Date date;

	/**
	 * Constructor with the date.
	 */
	/**
	 * @param date
	 *            The date. Can be any time in the past, present or future.
	 */
	public FixedDateProvider(Date date) {
		this.date = date;
	}

	/**
	 * Constructor with the date and an indicator of possible future date.
	 */
	/**
	 * @param date
	 *            The date.
	 * @param allowFutureDate
	 *            Indicate if a date in the future is allowed.
	 */
	public FixedDateProvider(Date date, boolean allowFutureDate) {
		this(date);

		if (!allowFutureDate) {
			// If a future date is not allowed, calculate the latest possible
			// date in the past/present.
			DateProvider local = new LocalDateProvider();
			Calendar crd = GregorianCalendar.getInstance();
			crd.setTime(date);
			Calendar now = GregorianCalendar.getInstance();
			now.setTime(local.getDate());
			Calendar acrd = GregorianCalendar.getInstance();
			acrd.setTime(adjustTime(crd.getTime()));
			if (now.before(crd)) {
				if (acrd.before(now)) {
					this.date = acrd.getTime();
				} else {
					this.date = now.getTime();
				}
			}
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.taleo.integration.client.customstep.lrd.DateProvider#getDate()
	 */
	public Date getDate() {
		return date;
	}
}
