package com.taleo.integration.client.customstep.tools.document;

import java.io.File;

import org.apache.commons.lang.ArrayUtils;

import eu.medsea.mimeutil.MimeType;
import eu.medsea.mimeutil.MimeUtil;

/**
 * Builder for DocumentInfo implementations.
 * <p>
 * Currently, only PDF files are supported. Other files return a default
 * DocumentInfo implementation that returns null values for unknown properties.
 * 
 * @author Romain Guay, Taleo Corporation
 * @deprecated No more necessary with the added Document.Code to build filename.
 * 
 */
public class DocumentInfoBuilder {

	public static final String PDF_MIME_TYPE = "application/pdf";

	/**
	 * Create a DocumentInfo on the given file.
	 * 
	 * @param file
	 * @return
	 */
	public DocumentInfo createDocumentInfo(File file) throws Exception {

		if (ArrayUtils
				.contains(getMimeTypes(file), new MimeType(PDF_MIME_TYPE))) {
			return new PdfDocumentInfo(file);

		} else {
			return new DefaultDocumentInfo(file);
		}
	}

	/**
	 * Indicates if the given file is supported with regards to extracting
	 * document information.
	 * 
	 * @param file
	 * @return
	 */
	public boolean isSupported(File file) {
		return ArrayUtils.contains(getMimeTypes(file), new MimeType(
				PDF_MIME_TYPE));
	}

	/**
	 * Get the Mime types for the given file.
	 * 
	 * @param file
	 * @return
	 */
	private MimeType[] getMimeTypes(File file) {
		return (MimeType[]) MimeUtil.getMimeTypes(file).toArray(
				new MimeType[] {});
	}

}
