package com.taleo.integration.client.customstep.util;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.TimeZone;

/**
 * Utility class for dates.
 * 
 * @author Romain Guay, Taleo Corporation
 * 
 */
public class DateUtils {

	/** Date format for ISO8601. */
	private static SimpleDateFormat ISO8601_FORMAT = new SimpleDateFormat(
			"yyyy-MM-dd'T'HH:mm:ssZ");

	/**
	 * Parse a date from an ISO8601 string.
	 * 
	 * @param date
	 *            The date string.
	 * @return
	 * @throws ParseException
	 */
	public static Date parseDateFromISO8601(String date) throws ParseException {
		// Remove the colon between hours and minutes in time zone.
		int index = date.lastIndexOf(':');
		date = date.substring(0, index) + date.substring(index + 1);

		return ISO8601_FORMAT.parse(date);
	}

	/**
	 * Format a date as an ISO8601 string.
	 * 
	 * @param date
	 *            The date.
	 * @return The date string in the default time zone.
	 */
	public static String formatDateAsISO8601(Date date) {
		// Make sure the time zone is set to the default.
		ISO8601_FORMAT.setTimeZone(TimeZone.getDefault());

		// Format the date.
		String result = ISO8601_FORMAT.format(date);

		// Add a colon between hours and minutes in time zone.
		// Example: YYYYMMDDTHH:mm:ss+HH00 --> YYYYMMDDTHH:mm:ss+HH:00
		result = result.substring(0, result.length() - 2) + ":"
				+ result.substring(result.length() - 2);

		return result;
	}

}
