package com.taleo.integration.client.customstep.util.csv;

/**
 * Class representing a sort criterion for CSV rows.
 * 
 * @author Romain Guay, Taleo Corporation
 */
public class SortCriterion {
	private int column;
	private boolean ascending = true;
	private boolean numeric = false;
	private boolean ignoreCase = true;

	/**
	 * Constructor with column index (0 based), ascending, numeric and
	 * ignoreCase flags.
	 * 
	 * @param column
	 * @param ascending
	 * @param numeric
	 * @param ignoreCase
	 */
	public SortCriterion(int column, boolean ascending, boolean numeric,
			boolean ignoreCase) {
		if (column < 0) {
			throw new IllegalArgumentException("Argument column must be >= 0");
		}
		this.column = column;
		this.ascending = ascending;
		this.numeric = numeric;
		this.ignoreCase = ignoreCase;
	}

	/**
	 * Constructor with column index (0 based), ascending and numeric flags.
	 * Ignore case is set to true.
	 * 
	 * @param column
	 * @param ascending
	 * @param numeric
	 */
	public SortCriterion(int column, boolean ascending, boolean numeric) {
		this(column, ascending, numeric, true);
	}

	/**
	 * Constructor with column index (0 based) and ascending flag. Numeric is
	 * set to false.
	 * 
	 * @param column
	 * @param ascending
	 */
	public SortCriterion(int column, boolean ascending) {
		this(column, ascending, false);
	}

	/**
	 * Constructor with column index (0 based). Ascending is set to true.
	 * 
	 * @param column
	 */
	public SortCriterion(int column) {
		this(column, true);
	}

	/**
	 * Column index.
	 * 
	 * @return
	 */
	public int getColumn() {
		return column;
	}

	/**
	 * Ascending flag.
	 * 
	 * @return
	 */
	public boolean isAscending() {
		return ascending;
	}

	/**
	 * Numeric flag.
	 * 
	 * @return
	 */
	public boolean isNumeric() {
		return numeric;
	}

	/**
	 * IgnoreCase flag.
	 * 
	 * @return
	 */
	public boolean isIgnoreCase() {
		return ignoreCase;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return "SortCriterion {column=" + column + "; ascending=" + ascending
				+ "; numeric=" + numeric + "; ignoreCase=" + ignoreCase + "}";
	}
}
