package com.taleo.integration.client.customstep.velocity;

import java.io.File;
import java.io.IOException;
import java.util.Date;

import com.taleo.integration.client.customstep.Constants;

/**
 * Class to expose file properties and content into Velocity templates.
 * 
 * @author Romain Guay - Taleo Corporation
 * 
 */
public class FileTool {

	/**
	 * Return the file last modified date.
	 * 
	 * @param filename
	 *            The filename.
	 * @return The file last modified date.
	 */
	public Date lastModified(String filename) {
		return new Date(new File(filename).lastModified());
	}

	/**
	 * Return the file size.
	 * 
	 * @param filename
	 *            The filename.
	 * @return The file size in bytes.
	 */
	public long size(String filename) {
		return new File(filename).length();
	}

	/**
	 * Return the file content.
	 * 
	 * @param filename
	 *            The filename.
	 * @return The file content.
	 * @throws IOException
	 */
	public String content(String filename) throws IOException {
		return content(filename, Constants.UTF8);
	}

	/**
	 * Return the file content.
	 * 
	 * @param filename
	 *            The filename.
	 * @param encoding
	 *            The encoding of the file.
	 * @return
	 * @throws IOException
	 */
	public String content(String filename, String encoding) throws IOException {
		return com.taleo.integration.client.customstep.util.FileUtils
				.readFileToString(new File(filename), encoding);
	}

	/**
	 * Return the line count.
	 * 
	 * @param filename
	 *            The filename.
	 * @return The line count.
	 * @throws IOException
	 */
	public int lineCount(String filename) throws IOException {
		return com.taleo.integration.client.customstep.util.FileUtils
				.getLineCount(new File(filename));
	}

}
