package com.taleo.integration.client.customstep.velocity;

import org.apache.commons.lang.StringUtils;

/**
 * Class to expose String functions into Velocity templates.
 * 
 * @author Romain Guay - Taleo Corporation
 * 
 */
public class StringTool {

	/**
	 * Right pad a string with the given pad string.
	 * 
	 * @param obj
	 *            The string or object to be converted to string.
	 * @param size
	 *            The total size after padding.
	 * @param padString
	 *            The pad string.
	 * @return The padded string.
	 */
	public String rightPad(Object obj, int size, String padString) {
		return StringUtils.rightPad(obj.toString(), size, padString);
	}

	/**
	 * Right pad a string with spaces.
	 * 
	 * @param obj
	 *            The string or object to be converted to string.
	 * @param size
	 *            The total size after padding.
	 * @return The padded string.
	 */
	public String rightPad(Object obj, int size) {
		return StringUtils.rightPad(obj.toString(), size);
	}

	/**
	 * Left pad a string with the given pad string.
	 * 
	 * @param obj
	 *            The string or object to be converted to string.
	 * @param size
	 *            The total size after padding.
	 * @param padString
	 *            The pad string.
	 * @return The padded string.
	 */
	public String leftPad(Object obj, int size, String padString) {
		return StringUtils.leftPad(obj.toString(), size, padString);
	}

	/**
	 * Left pad a string with spaces.
	 * 
	 * @param obj
	 *            The string or object to be converted to string.
	 * @param size
	 *            The total size after padding.
	 * @return The padded string.
	 */
	public String leftPad(Object obj, int size) {
		return StringUtils.leftPad(obj.toString(), size);
	}

	/**
	 * Get the length of the given string.
	 * 
	 * @param obj
	 *            The string or object to be converted to string.
	 * @return The length.
	 */
	public int length(Object obj) {
		return obj.toString().length();
	}

	/**
	 * Gets a substring from the specified String.
	 * 
	 * @param obj
	 *            The string or object to be converted to string.
	 * @param beginIndex
	 *            The begin index.
	 * @param endIndex
	 *            The end index.
	 * @return The substring.
	 */
	public String substring(Object obj, int beginIndex, int endIndex) {
		return StringUtils.substring(obj.toString(), beginIndex, endIndex);
	}

	/**
	 * Gets the substring after the first occurrence of a separator.
	 * 
	 * @param obj
	 *            The string or object to be converted to string.
	 * @param separator
	 *            The separator string.
	 * @return The substring.
	 */
	public String substringAfter(Object obj, String separator) {
		return StringUtils.substringAfter(obj.toString(), separator);
	}

	/**
	 * Gets the substring after the last occurrence of a separator.
	 * 
	 * @param obj
	 *            The string or object to be converted to string.
	 * @param separator
	 *            The separator string.
	 * @return The substring.
	 */
	public String substringAfterLast(Object obj, String separator) {
		return StringUtils.substringAfterLast(obj.toString(), separator);
	}

	/**
	 * Gets the substring before the first occurrence of a separator.
	 * 
	 * @param obj
	 *            The string or object to be converted to string.
	 * @param separator
	 *            The separator string.
	 * @return The substring.
	 */
	public String substringBefore(Object obj, String separator) {
		return StringUtils.substringBefore(obj.toString(), separator);
	}

	/**
	 * Gets the substring before the last occurrence of a separator.
	 * 
	 * @param obj
	 *            The string or object to be converted to string.
	 * @param separator
	 *            The separator string.
	 * @return The substring.
	 */
	public String substringBeforeLast(Object obj, String separator) {
		return StringUtils.substringBeforeLast(obj.toString(), separator);
	}

	/**
	 * Converts all of the characters to upper case.
	 * 
	 * @param obj
	 *            The string or object to be converted to string.
	 * @return The string to upper case.
	 */
	public String toUpperCase(Object obj) {
		return obj.toString().toUpperCase();
	}

	/**
	 * Converts all of the characters to lower case.
	 * 
	 * @param obj
	 *            The string or object to be converted to string.
	 * @return The string to lower case.
	 */
	public String toLowerCase(Object obj) {
		return obj.toString().toLowerCase();
	}

	/**
	 * Concatenate two strings.
	 * 
	 * @param obj1
	 *            The first string or object to be converted to string.
	 * @param obj2
	 *            The second string or object to be converted to string.
	 * @return The string to lower case.
	 */
	public String concat(Object obj1, Object obj2) {
		return obj1.toString().concat(obj2.toString());
	}

	/**
	 * Check if the first argument string contains the second argument string.
	 * 
	 * @param obj1
	 *            The first string or object to be converted to string.
	 * @param obj2
	 *            The second string or object to be converted to string.
	 * @return <code>true</code> if the first argument string contains the
	 *         second, <code>false</code> otherwise.
	 */
	public boolean contains(Object obj1, Object obj2) {
		return StringUtils.contains(obj1.toString(), obj2.toString());
	}

	/**
	 * Check if the first argument string starts with the second argument
	 * string.
	 * 
	 * @param obj1
	 *            The first string or object to be converted to string.
	 * @param obj2
	 *            The second string or object to be converted to string.
	 * @return <code>true</code> if the first argument string starts with the
	 *         second, <code>false</code> otherwise.
	 */
	public boolean startsWith(Object obj1, Object obj2) {
		return obj1.toString().startsWith(obj2.toString());
	}

	/**
	 * Check if the first argument string ends with the second argument string.
	 * 
	 * @param obj1
	 *            The first string or object to be converted to string.
	 * @param obj2
	 *            The second string or object to be converted to string.
	 * @return <code>true</code> if the first argument string ends with the
	 *         second, <code>false</code> otherwise.
	 */
	public boolean endsWith(Object obj1, Object obj2) {
		return obj1.toString().endsWith(obj2.toString());
	}

	/**
	 * Check if the first argument string matches the regex pattern in the
	 * second argument string.
	 * 
	 * @param obj1
	 *            The first string or object to be converted to string.
	 * @param obj2
	 *            The second string or object to be converted to string.
	 * @return <code>true</code> if the first argument string matches the regex
	 *         pattern in the second, <code>false</code> otherwise.
	 */
	public boolean matches(Object obj1, Object obj2) {
		return obj1.toString().matches(obj2.toString());
	}

}
