package com.taleo.integration.client.customstep.velocity;

import java.util.Date;

import com.taleo.integration.client.customstep.lrd.RunDateManager;
import com.taleo.ws.integration.client.GlobalConfig;
import com.taleo.ws.integration.client.Pipeline;

/**
 * Class to expose workflow variables into Velocity templates.
 * 
 * @author Romain Guay - Taleo Corporation
 */
public class WorkflowTool {

	private Date runDate;
	private Date lastRunDate;
	private Date effectiveRunDate;

	/**
	 * Constructor with the pipeline and the config.
	 * 
	 * @param pipeline
	 *            The worflow pipeline.
	 * @param config
	 *            The workflow config.
	 */
	public WorkflowTool(Pipeline pipeline, GlobalConfig config) {

		if (pipeline != null) {
			// Get the RunDateManager from the context.
			RunDateManager runDateManager = (RunDateManager) pipeline
					.documentProperties().get(RunDateManager.PIPELINE_KEY);

			// Get RunDateManager properties.
			if (runDateManager != null) {
				this.runDate = runDateManager.getRunDate();
				this.lastRunDate = runDateManager.getLastRunDate();
				this.effectiveRunDate = runDateManager.getEffectiveRunDate();
			}
		}

		// TODO: Extract the run date in the case of the standard LRD step.

		// TODO: Extract parameters from the config (zone, product, ...)

	}

	/**
	 * Get the current run date.
	 */
	public Date getRunDate() {
		return runDate;
	}

	/**
	 * Get the last run date.
	 */
	public Date getLastRunDate() {
		return lastRunDate;
	}

	/**
	 * Get the effective run date that is used for filtering.
	 */
	public Date getEffectiveRunDate() {
		return effectiveRunDate;
	}

}
