<?xml version="1.0" encoding="UTF-8"?>
	<!--
		====================================================================
	-->
	<!--
		Extract the list of indexes (0 based) for projections that have a
		given tag defined.
	-->
	<!--
		Multiple tags can be set in the projection tag attribute, separating
		them with a space.
	-->
	<!--
		Example: <quer:projection alias="number" tag="key parentKey"/>
	-->
	<!-- Parameters:
	 - tagName: The searched tag name (e.g. 'key'). 
-->
	<!-- The result is a simple list of comma delimited indexes. -->
	<!--
		====================================================================
	-->
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:quer="http://www.taleo.com/ws/integration/query"
	xmlns:fct="http://www.taleo.com/xsl_functions" xmlns:xs="http://www.w3.org/2001/XMLSchema"
	exclude-result-prefixes="fct xs">
	<xsl:output method="text" />
	<xsl:param name="tagName" />
	<!--
		====================================================================
	-->
	<!-- Do not render unmatched text. -->
	<!--
		====================================================================
	-->
	<xsl:template match="text()" />
	<!--
		====================================================================
	-->
	<!-- Match projections and collect their indexes. -->
	<!--
		====================================================================
	-->
	<xsl:template match="/quer:query/quer:projections">
		<xsl:variable name="lastIndex">
			<xsl:value-of
				select="count(quer:projection[fct:list-includes(@tag, $tagName)])" />
		</xsl:variable>
		<xsl:for-each select="quer:projection[fct:list-includes(@tag, $tagName)]">
			<xsl:variable name="number">
				<xsl:number />
			</xsl:variable>
			<xsl:value-of select="$number - 1" />
			<xsl:if test="position() &lt; $lastIndex">
				<xsl:text>,</xsl:text>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	<!--
		====================================================================
	-->
	<!--
		Indicate if a list of space separated elements includes the given
		element.
	-->
	<!-- Params: -->
	<!-- list: The list content. -->
	<!-- element: The element searched for. -->
	<!--
		====================================================================
	-->
	<xsl:function name="fct:list-includes" as="xs:boolean">
		<xsl:param name="list" />
		<xsl:param name="element" />
		<xsl:value-of select="index-of(tokenize($list, '\s+'), $element) &gt; 0" />
	</xsl:function>
</xsl:stylesheet>
