<?xml version="1.0" encoding="UTF-8"?>
	<!--
		====================================================================
	-->
	<!--
		This stylesheet transforms LRD filtering to limit result only to
		records that were created (not updated) in the time interval.
	-->
	<!--
		This applies to cases where there are multiple LRD filters in the same
		query. In those cases, it is possible to identify which one targets
		created records by adding a tag "create" to the <quer:lrd>, for
		example: <quer:lrd tag="create"> <quer:field path="CreationDate"/>
		</quer:lrd>
	-->
	<!--
		The purpose of doing that is related to looping and merging. In fact,
		when we do time increment looping, the same records will come out
		every time they match one of the LRD filter in successive time
		increments. There are situations where we can focus only on created
		records, it is the case when we do initial or termination extracts
		starting on day 1 of the zone. Doing that optimizes those extracts by
		eliminating unneeded duplicates.
	-->
	<!--
		There needs to be at least one LRD filter with a "create" tag for this
		transformation to do anything.
	-->
	<!--
		====================================================================
	-->
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:quer="http://www.taleo.com/ws/integration/query"
	xmlns:fct="http://www.taleo.com/xsl_functions" xmlns:xs="http://www.w3.org/2001/XMLSchema"
	exclude-result-prefixes="fct xs">
	<xsl:output method="xml" encoding="UTF-8" indent="yes" />
	<!--
		====================================================================
	-->
	<!--
		Get the count of LRD filters with a "create" tag and cascade down.
	-->
	<!--
		====================================================================
	-->
	<xsl:template match="/">
		<xsl:variable name="TagCount">
			<xsl:value-of select="count(//quer:lrd[fct:list-includes(@tag, 'create')])" />
		</xsl:variable>
		<xsl:copy>
			<xsl:apply-templates>
				<xsl:with-param name="TagCount" select="$TagCount" />
			</xsl:apply-templates>
		</xsl:copy>
	</xsl:template>
	<!--
		====================================================================
	-->
	<!--
		Identity template renders nodes as is by default with the TagCount
		parameter.
	-->
	<!--
		====================================================================
	-->
	<xsl:template match="@*|*|processing-instruction()|comment()">
		<xsl:param name="TagCount" />
		<xsl:copy>
			<xsl:apply-templates select="*|@*|text()|processing-instruction()|comment()">
				<xsl:with-param name="TagCount" select="$TagCount" />
			</xsl:apply-templates>
		</xsl:copy>
	</xsl:template>
	<!--
		====================================================================
	-->
	<!-- Template that applies the transformation to the LRD filter. -->
	<!--
		====================================================================
	-->
	<xsl:template match="quer:lrd">
		<xsl:param name="TagCount" />
		<xsl:choose>
			<xsl:when test="$TagCount = 0 or fct:list-includes(@tag, 'create')">
				<!-- Render as is. -->
				<xsl:copy>
					<xsl:apply-templates />
				</xsl:copy>
			</xsl:when>
			<xsl:otherwise>
				<!-- Deactivate the filter. -->
				<quer:equal>
					<quer:integer>0</quer:integer>
					<quer:integer>1</quer:integer>
				</quer:equal>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
		====================================================================
	-->
	<!--
		Indicate if a list of space separated elements includes the given
		element.
	-->
	<!-- Params: -->
	<!-- list: The list content. -->
	<!-- element: The element searched for. -->
	<!--
		====================================================================
	-->
	<xsl:function name="fct:list-includes" as="xs:boolean">
		<xsl:param name="list" />
		<xsl:param name="element" />
		<xsl:value-of select="index-of(tokenize($list, '\s+'), $element) &gt; 0" />
	</xsl:function>
</xsl:stylesheet>
